/**
 * The MIT License (MIT)
 *
 * Copyright (C) 2016 Yahoo Japan Corporation.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

import Foundation

extension XML {
    open class Element {
        open var name: String
        open var text: String?
        open var attributes: [String: String]
        open var childElements: [Element]
        open var lineNumberStart: Int
        open var lineNumberEnd: Int
        open var CDATA: Data?
        open var ignoreNamespaces: Bool
        
        // for println
        open weak var parentElement: Element?

        public init(
            name: String,
            text: String? = nil,
            attributes: [String: String] = [:],
            childElements: [Element] = [],
            lineNumberStart: Int = -1,
            lineNumberEnd: Int = -1,
            CDATA: Data? = nil,
            ignoreNamespaces: Bool = false
        ) {
            self.name = name
            self.text = text
            self.attributes = attributes
            self.childElements = childElements
            self.lineNumberStart = lineNumberStart
            self.lineNumberEnd = lineNumberEnd
            self.CDATA = CDATA
            self.ignoreNamespaces = ignoreNamespaces
        }
    }
}
